#
# spec file for package mcelog
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           mcelog
License:        GPLv2+
Summary:        Log Machine Check Events
Version:        1.0pre3.6363f5b719e9
Release:        4.5.1
AutoReqProv:    on
ExclusiveArch:  x86_64
BuildRequires:  libesmtp-devel
Requires:       logrotate
PreReq:         %insserv_prereq %fillup_prereq
Source:         mcelog-%{version}.tar.bz2
Source1:        mcelog.service
Source2:        mcelog.sysconfig
Source6:        README.email_setup
Patch1:         email.patch
Group:          System/Monitoring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mcelog retrieves machine check events from an x86-64 kernel in a cron
job, decodes them, and logs them to /var/log/mcelog.

A machine check event is a hardware error detected by the CPU.

It should run on any x86-64 system.

In addition, it allows decoding machine check kernel panic messages.



Authors:
--------
    Andi Kleen <andi@firstfloor.org>

%prep
%setup
%patch1 -p1

%build
export SUSE_ASNEEDED=0
make CFLAGS="$RPM_OPT_FLAGS"

%install 
export prefix=$RPM_BUILD_ROOT/usr
export etcprefix=$RPM_BUILD_ROOT
make -e install
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d/
mkdir -p $RPM_BUILD_ROOT/etc/init.d
install -m755 %SOURCE1 $RPM_BUILD_ROOT/etc/init.d/mcelog
ln -s /etc/init.d/mcelog $RPM_BUILD_ROOT/usr/sbin/rcmcelog
install -m644 mcelog.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/mcelog

mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 %SOURCE2 $RPM_BUILD_ROOT/var/adm/fillup-templates/sysconfig.mcelog

mkdir -p $RPM_BUILD_ROOT/%_docdir/%name
install -m 644 %SOURCE6 $RPM_BUILD_ROOT/%_docdir/%name/README.email_setup
install -m 644 lk10-mcelog.pdf $RPM_BUILD_ROOT/%_docdir/%name/lk10-mcelog.pdf

%clean
rm -rf $RPM_BUILD_ROOT

%post
if [ -w /etc/sysconfig/mcelog ];then
    sed -ie 's/MCELOG_ADMIN_EMAIL="trenn@suse.de"/MCELOG_ADMIN_EMAIL=""/' /etc/sysconfig/mcelog
fi
if [ -c /dev/mcelog ];then
    %{fillup_and_insserv -y mcelog}
fi

%preun
%{stop_on_removal mcelog}

%postun
%{restart_on_update mcelog}
%insserv_cleanup

%files
%defattr (-,root,root,755)
%{_mandir}/man8/*
/usr/sbin/mcelog
%config /etc/logrotate.d/mcelog
/etc/init.d/mcelog
%dir /etc/mcelog
%config /etc/mcelog/mcelog.conf
/var/adm/fillup-templates/sysconfig.mcelog
/etc/mcelog/*trigger
/usr/sbin/rcmcelog
%_docdir/%name

%changelog
* Mon Aug 29 2011 trenn@suse.de
- Remove trenn@suse.de from sysconfig (bnc#713562)
* Mon Oct 25 2010 trenn@suse.de
- Add Sandybridge/Westmere decode support
- Fix domainname for email notification
- Update to latest git version
* Thu Feb 18 2010 ro@suse.de
- Update to version 1.0pre3
  - Boxboro-EX enhancements
  - Bugfixes
  Minor pidfile handling adjusting in service file
- Added missing conf file and trigger scripts
* Thu Dec  3 2009 trenn@suse.de
- Minor .spec and init script fixes/cleanups
* Thu Dec  3 2009 trenn@suse.de
- Add service parts:
  - let mcelog --daemon handle pid file in /var/run/mcelog.pid
  - add insserv logic
  - remove cron.daily script in update case
* Fri Nov 27 2009 trenn@suse.de
- Update to latest git version (called it 1.0pre1 myself, may differ
  with a possible public 1.0pre1 version), this includes
  following new featues:
  - yellow bit support
  - page predictive failure analysis support
  - Initial memdb support
    This allows to account memory errors in memory in daemon mode
    And a lot more...
* Fri Oct  2 2009 trenn@suse.de
- Update to latest git version (0.9pre)
  Introduces mcelog damon mode, service file will follow in an
  extra commit.
* Fri Jan  9 2009 olh@suse.de
- use ExclusiveArch as in /SRC/arch/
* Sat Sep 27 2008 trenn@suse.de
- fate #304279 mcelog support for Tigerton/Dunnington
  Patch is from Andi himself with this statement:
  While it looks large most of it is just new tables.
* Mon May 29 2006 ak@suse.de
- decode intel thermal events too (#179327)
* Fri May  5 2006 ak@suse.de
- Update to 0.7.  This fixes
  - Fix --dmi option (#166324)
  - Incorporate old patches
* Fri Mar  3 2006 ak@suse.de
- Avoid cosmetic problem in --filter (#153347)
* Wed Feb  8 2006 ak@suse.de
- update to mcelog 0.6
  * Fixes bugs (#148869, #137985)
  * Adds --dmi option to map addresses to DIMMs using SMBIOS
    (default to off)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 sf@suse.de
- update to version 0.5
  * Clarify --ascii in the manpage
  * Support for AMD K8 Revision F machine check DRAM error
  thresholding
* Fri Feb 11 2005 ak@suse.de
- Use RPM_OPT_FLAGS
- Improve description again
* Thu Feb 10 2005 ak@suse.de
- mcelog-0.4:
  * add support to decode AMD K8 (Opteron/Athlon64/AthlonFX) and
    Intel P4 (Xeon and Pentium 4) events
  * add --ascii option to decode machine check panic information
- Rewrite description in .spec file
* Wed Jun  9 2004 ak@suse.de
- memlog-0.2:
  * fix mcelog looping (#41863)
  * Add GPL notices
* Thu Mar 25 2004 sf@suse.de
- initial version
- fixes #36898
